.. _in_install:

Get Arbor
=========

To get started quickly with Arbor using its Python API on your personal machine, we advise that you install Arbor's Python package. If you wish to use the C++ API, you can use the Spack package, or build Arbor from source. Note that you can also build the Python bindings using these methods.

.. toctree::
   :maxdepth: 1

   python
   spack
   build_install
